@@ -1,7 +1,7 @@
 #------------------------------------------------------------------------------- 
 # 
 # File: pk_cgi.pm
-# Version: 0.4.2
+# Version: 0.4
 # Author: Jeremy Wall
 # Definition: Contains all the code to handle working in the CGI environment.
 #             This includes building a page for transmitting to a browser,
@@ -13,7 +13,7 @@ package EasyCGI;
 require Exporter;
 use strict;
 
-my $VERSION = 0.4.2;
+my $VERSION = 0.40;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(cgi_request get_cookie_list get_cookie);
@@ -27,7 +27,6 @@ sub cgi_request {
     
     if (exists $ENV{REQUEST_METHOD}) {
         if ($ENV{REQUEST_METHOD} eq "GET") {
-            $ENV{"QUERY_STRING"} =~ s/\+/ /g;
             %get_vars = $ENV{"QUERY_STRING"} =~ m/(?:\A|&)([^=]+)=([^&]+)/g;
             $get_vars{Method} = $ENV{REQUEST_METHOD};
             return %get_vars;
@@ -225,24 +224,23 @@ return 1;
 
 =head1 Name
 
-CGI::EasyCGI - Lightweight Perl module for handling the most common CGI functions. Simple to use, single file with no dependencies, and short learning curve
+cgi::pk_cgi - Lightweight Perl module for handling the most common CGI functions. Simple to use, single file with no dependencies, and short learning curve
 for those times when you don't want or need the swiss army knife of cgi modules.
 
 =head1 Synopsis
     
-use CGI::EasyCGI;
+use cgi::pk_cgi;
     
-my $Page =  EasyCGI->new_page("html");
+my $Page = pk_cgi->new_page("html");
     
 my $Cookie = {Name => "pklogin", Value => {UserName => $Self->{Env}{username}, Password => $Self->{Env}{password}};
 $Page->add_cookie($Cookie);
     
-%PKEnv = EasyCGI::cgi_request() 
+%PKEnv = pk_cgi::cgi_request() 
        or die "No Http Environment";
     
-%Cookies = EasyCGI::get_cookie_list()
-        or die "no cookies";
-          
+%Cookies = pk_cgi::get_cookie_list()
+        or die "no cookies";  
 $SomeCookie = $Cookies{SomeCookieName};
 $SomeCookieValue = $$SomeCookie(SomeCookieVariable};
          
@@ -336,7 +334,7 @@ cannot be changed and no more cookies can be set.
 
 =head1 Version
 
-0.4.1
+0.4
 Written 02-04-2004
 
 =head1 Author
@@ -351,11 +349,11 @@ it under the same terms as Perl itself.
 This script requires the C<strict> module.
 It also requires the C<Exporter> nmodule
  
-=head1 OSNAMES
+=pod OSNAMES
 
 Any
 
-=head1 SCRIPT CATEGORIES
+=pod SCRIPT CATEGORIES
 
 CGI
 
